@@ -59,7 +59,13 @@ class FileDebugStream : public QIODevice
         outputFile.close();
       }
 
-      qt_message_output( mType, buf.trimmed().constData() );
+      qt_message_output( mType,
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+                         QMessageLogContext(),
+                         QString::fromLatin1(buf.trimmed()) );
+#else
+                         buf.trimmed().constData() );
+#endif
       return len;
     }
 
@@ -150,7 +156,7 @@ void akInit( const QString &appName )
     QFile fileOld( infoOld.absoluteFilePath() );
     const bool success = fileOld.remove();
     if ( !success )
-      qFatal( "Cannot remove old log file - running on a readlony filesystem maybe?" );
+      qFatal( "Cannot remove old log file - running on a readonly filesystem maybe?" );
   }
   QFileInfo info( sInstance()->errorLogFileName() );
   if ( info.exists() ) {
